## $Id: utils.py 17486 2023-07-13 13:50:48Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Customize general helper utilities for Kofa.
"""
from kofacustom.nigeria.utils.utils import NigeriaKofaUtils

class CustomKofaUtils(NigeriaKofaUtils):
    """A collection of methods subject to customization.
    """

    APP_CATS_DICT = {
        'basic': 'UAS, PUTME, PUDE, PCE, PRENCE',
        'no': 'No Application',
        'rnnurse': 'RN Nursing',
        'ndnurse': 'ND Nursing',
        }

    DEGREES_DICT = {
        'BA': 'Bachelor of Arts',
        'BAGR': 'Bachelor of Agriculture',
        'LLB': 'Bachelor of Laws',
        'MA': 'Master of Arts',
        'MBA': 'Master of Business Administration',
        'MUSM': 'Master of Music',
        'LLM': 'Master of Laws',
        'DBA': 'Doctor of Business Administration',
        'PHD': 'Doctor of Philosophy',
        'MD': 'Doctor of Medicine',
        'RN': 'Registered Nursing',
        'RM': 'Registered Midwifery',
        'ND': 'National Diploma Nursing',
        'HND': 'Higher National Diploma Public Health',
        }

    EXAM_GRADES = (
        ('A1', 'Excellent (A1)'),
        ('A2', 'Very Good (A2)'),
        ('A3', 'Good (A3)'),
        ('B2', 'Very Good (B2)'),
        ('B3', 'Good (B3)'),
        ('C4', 'Credit (C4)'),
        ('C5', 'Credit (C5)'),
        ('C6', 'Credit (C6)'),
        #('A', 'Pass (A)'),
        #('B', 'Pass (B)'),
        #('C', 'Pass (C)'),
        #('U', 'Pass (U)'),
        #('D7', 'Pass (D7)'),
        #('P7', 'Pass (P7)'),
        #('P8', 'Pass (P8)'),
        #('E8', 'Pass (E8)'),
        #('F9', 'Fail (F9)'),
        #('Aa', 'A (a)'),
        #('Bb', 'B (b)'),
        #('Cc', 'C (c)'),
        #('Dd', 'D (d)'),
        #('Ee', 'E (e)'),
        #('Ff', 'F (f)'),
        #('Gg', 'G (g)'),
        #('credit-1', 'Credit-1'),
        #('credit-2', 'Credit-2'),
        ('dist', 'Distinction'),
        #('pass', 'Pass'),
        #('AR', 'Awaiting Results'),
        )

    PAYMENT_CATEGORIES = {
        'schoolfee': 'School Fee (total amount)',
        'schoolfee_1': 'School Fee (1st instalment)',
        'secondinstal': 'School Fee (2nd instalment)',
        'clearance': 'Acceptance Fee',
        'hostel':'Hostel Fee (1st instalment)',
        'hostel_2':'Hostel Fee (2nd instalment)',
        'hostel_total':'Hostel Fee (full payment)',
        #'bed_allocation': 'Bed Allocation Fee',
        #'hostel_maintenance': 'Hostel Maintenance Fee',
        #'transfer': 'Transfer Fee',
        #'gown': 'Gown Hire Fee',
        'application': 'Application Fee',
        #'app_balance': 'Application Fee Balance',
        'transcript': 'Transcript Fee',
        #'late_registration': 'Late Course Registration Fee',
        #'combi': 'Combi Payment',
        'resit': 'Resit Fee',
        }

    SELECTABLE_PAYMENT_CATEGORIES = {
        'schoolfee': 'School Fee (total amount)',
        'schoolfee_1': 'School Fee (1st instalment)',
        'secondinstal': 'School Fee (2nd instalment)',
        'hostel':'Hostel Fee (1st instalment)',
        'hostel_2':'Hostel Fee (2nd instalment)',
        'hostel_total':'Hostel Fee (full payment)',
        'resit': 'Resit Fee',
        }

    def selectable_payment_categories(self, student):
        return self.SELECTABLE_PAYMENT_CATEGORIES

    PREVIOUS_PAYMENT_CATEGORIES = {
        'schoolfee': 'School Fee',
        'hostel':'Hostel Fee',
        }

    REPORTABLE_PAYMENT_CATEGORIES = {
        'schoolfee': 'School Fee',
        }

    BALANCE_PAYMENT_CATEGORIES = {
        'schoolfee': 'School Fee',
        'hostel':'Hostel Fee',
        }

    COMBI_PAYMENT_CATEGORIES = {
        }

    STUDY_MODES_DICT = {
        'ug_ft': 'Undergraduate Full Time',
        #'no': 'no application',
        'basic_mid':'Basic Midwifery',
        'basic_nurs':'Basic Nursing',
        'post_mid':'Post Midwifery',
        'post_nurs':'Post Nursing',
        'dp_nurs':'Diploma Nursing',
        'post_bph':'Post Basic Public Health',
        }

    MODE_GROUPS = {
        'All': ('all',),
        'Undergraduate Full-Time': ('ug_ft',),
        'Basic Midwifery': ('basic_mid',),
        'Basic Nursing': ('basic_nurs',),
        'Post Midwifery': ('post_mid',),
        'Post Nursing': ('post_nurs',),
        }